@@ -1,4 +1,7 @@
-import json
+try:
+  import json
+except ImportError:
+  import simplejson as json
 from createsend import CreateSendBase
 from utils import json_to_py
 
