@@ -7,7 +7,7 @@ from StringIO import StringIO
 from urlparse import urlparse
 from utils import json_to_py, get_faker
 
-__version_info__ = ('1', '0', '0')
+__version_info__ = ('1', '0', '1')
 __version__ = '.'.join(__version_info__)
 
 class CreateSendError(Exception):
@@ -97,8 +97,8 @@ class CreateSendBase(object):
   def _put(self, path, body="", params={}):
     return self.make_request(path=path, method="PUT", params=params, body=body)
 
-  def _delete(self, path):
-    return self.make_request(path=path, method="DELETE")
+  def _delete(self, path, params={}):
+    return self.make_request(path=path, method="DELETE", params=params)
 
 class CreateSend(CreateSendBase):
   """Provides high level CreateSend functionality/data you'll probably need."""
